@@ -36,6 +36,20 @@ Warnings
 **************************************************************************************************/
 #include "Warnings.h"
 
+/**************************************************************************************************
+Override (define in MSVC)
+**************************************************************************************************/
+#ifdef _MSC_VER
+#define APE_OVERRIDE override
+#else
+#define APE_OVERRIDE
+#endif
+
+/**************************************************************************************************
+NULL (define to nullptr on all platforms)
+**************************************************************************************************/
+#define APE_NULL nullptr
+
 /**************************************************************************************************
 Global includes
 **************************************************************************************************/
@@ -54,7 +68,7 @@ Global includes
     #ifdef _MSC_VER
         #pragma warning(push) // push and pop warnings because the windows includes suppresses some like 4514
     #endif
-    #include <windows.h>
+    #include <Windows.h>
     #ifdef _MSC_VER
         #pragma warning(pop)
     #endif
@@ -71,7 +85,7 @@ Global includes
 #endif
 #define ape_max(a,b)    (((a) > (b)) ? (a) : (b))
 #define ape_min(a,b)    (((a) < (b)) ? (a) : (b))
-#define APE_CLEAR(destination) memset(&destination, 0, sizeof (destination))
+#define APE_CLEAR(destination) memset(&destination, 0, sizeof(destination))
 
 /**************************************************************************************************
 Packing
@@ -93,7 +107,7 @@ Version
 #include "Version.h"
 
 // year in the copyright strings
-#define MAC_YEAR 2022
+#define MAC_YEAR 2023
 
 // build the version string
 #define STRINGIZE2(s) #s
@@ -117,7 +131,8 @@ Version
 Global compiler settings (useful for porting)
 **************************************************************************************************/
 // assembly code (helps performance, but limits portability)
-#if defined __SSE2__
+// we target SSE2 as a minimum on the 32-bit now, so it should be possible to always enable that (unless we're on Android)
+#if defined(__SSE2__) || defined(_M_IX86) || defined(_M_X64)
     #define ENABLE_SSE_ASSEMBLY
 #endif
 
@@ -127,7 +142,6 @@ Global compiler settings (useful for porting)
 
 #ifdef _MSC_VER // doesn't compile in gcc
     #if defined(_M_IX86) || defined(_M_X64)
-        #define ENABLE_SSE_ASSEMBLY
         #define ENABLE_AVX_ASSEMBLY
     #endif
 #endif
@@ -187,14 +201,17 @@ Global macros
 
 #define APE_TRUNCATE ((size_t)-1)
 
-#define POINTER_TO_INT64(POINTER) static_cast<int64>(reinterpret_cast<uintptr_t>(POINTER))
+// we use this to check for zero because Clang warns if we just equate a double with zero
+#define APE_DOUBLE_ZERO 0.00001
+
+#define POINTER_TO_INT64(POINTER) static_cast<APE::int64>(reinterpret_cast<uintptr_t>(POINTER))
 
 #if defined(PLATFORM_WINDOWS)
     #define IO_USE_WIN_FILE_IO
     #define DLLEXPORT                                   __declspec(dllexport)
     #define SLEEP(MILLISECONDS)                         ::Sleep(MILLISECONDS)
     #define MESSAGEBOX(PARENT, TEXT, CAPTION, TYPE)     ::MessageBox(PARENT, TEXT, CAPTION, TYPE)
-    #define PUMP_MESSAGE_LOOP                           { MSG Msg; while (PeekMessage(&Msg, NULL, 0, 0, PM_REMOVE) != 0) { TranslateMessage(&Msg); DispatchMessage(&Msg); } }
+    #define PUMP_MESSAGE_LOOP                           { MSG Msg; while (PeekMessage(&Msg, APE_NULL, 0, 0, PM_REMOVE) != 0) { TranslateMessage(&Msg); DispatchMessage(&Msg); } }
     #define ODS                                         OutputDebugString
     #define TICK_COUNT_TYPE                             unsigned long long
     #define TICK_COUNT_READ(VARIABLE)                   VARIABLE = GetTickCount64()
@@ -265,7 +282,7 @@ namespace APE
         MODE_CONVERT,
         MODE_MAKE_APL,
         MODE_CHECK,
-        MODE_COUNT,
+        MODE_COUNT
     };
 }
 
@@ -280,7 +297,9 @@ Global defines
 #endif
 #define APE_BYTES_IN_KILOBYTE            1024
 #define APE_BYTES_IN_MEGABYTE            1048576
-#define APE_BYTES_IN_GIGABYTE            int64(1073741824)
+#define APE_BYTES_IN_GIGABYTE            APE::int64(1073741824)
+
+#define APE_WAV_HEADER_OR_FOOTER_MAXIMUM_BYTES (APE_BYTES_IN_MEGABYTE * 8)
 
 /**************************************************************************************************
 Byte order
@@ -298,11 +317,11 @@ Channels
 /**************************************************************************************************
 Macros
 **************************************************************************************************/
-#define MB(TEST) MESSAGEBOX(NULL, TEST, _T("Information"), MB_OK);
-#define MBN(NUMBER) { TCHAR cNumber[16]; _stprintf(cNumber, _T("%d"), NUMBER); MESSAGEBOX(NULL, cNumber, _T("Information"), MB_OK); }
+#define MB(TEST) MESSAGEBOX(APE_NULL, TEST, _T("Information"), MB_OK);
+#define MBN(NUMBER) { TCHAR cNumber[16]; _stprintf(cNumber, _T("%d"), NUMBER); MESSAGEBOX(APE_NULL, cNumber, _T("Information"), MB_OK); }
 
-#define SAFE_DELETE(POINTER) if (POINTER) { delete POINTER; POINTER = NULL; }
-#define SAFE_ARRAY_DELETE(POINTER) if (POINTER) { delete [] POINTER; POINTER = NULL; }
+#define SAFE_DELETE(POINTER) if (POINTER) { delete POINTER; POINTER = APE_NULL; }
+#define SAFE_ARRAY_DELETE(POINTER) if (POINTER) { delete [] POINTER; POINTER = APE_NULL; }
 #define SAFE_VOID_CLASS_DELETE(POINTER, Class) { Class *pClass = (Class *) POINTER; if (pClass) { delete pClass; POINTER = NULL; } }
 #define SAFE_FILE_CLOSE(HANDLE) if (HANDLE != INVALID_HANDLE_VALUE) { CloseHandle(HANDLE); HANDLE = INVALID_HANDLE_VALUE; }
 
@@ -310,11 +329,11 @@ Macros
 
 #define CATCH_ERRORS(CODE) try { CODE } catch(...) { }
 
-#define RETURN_ON_ERROR(FUNCTION) {    int nFunctionResult = FUNCTION; if (nFunctionResult != 0) { return nFunctionResult; } }
+#define RETURN_ON_ERROR(FUNCTION) { const int nFunctionResult = static_cast<int>(FUNCTION); if (nFunctionResult != ERROR_SUCCESS) { return nFunctionResult; } }
 #define RETURN_VALUE_ON_ERROR(FUNCTION, VALUE) { int nFunctionResult = FUNCTION; if (nFunctionResult != 0) { return VALUE; } }
 #define RETURN_ON_EXCEPTION(CODE, VALUE) { try { CODE } catch(...) { return VALUE; } }
 
-#define THROW_ON_ERROR(CODE) { intn nThrowResult = static_cast<intn> (CODE); if (nThrowResult != 0) throw(nThrowResult); }
+#define THROW_ON_ERROR(CODE) { const intn nThrowResult = static_cast<intn> (CODE); if (nThrowResult != 0) throw(nThrowResult); }
 
 #define EXPAND_8_TIMES(CODE) CODE CODE CODE CODE CODE CODE CODE CODE
 #define EXPAND_9_TIMES(CODE) CODE CODE CODE CODE CODE CODE CODE CODE CODE
